@@ -302,7 +302,7 @@ CREATE TABLE "release"
     protocol          TEXT,
     implementation    TEXT,
     timestamp         TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
-    announce_type     TEXT      DEFAULT 'NEW', 
+    announce_type     TEXT      DEFAULT 'NEW',
     info_url          TEXT,
     download_url      TEXT,
     group_id          TEXT,
@@ -1698,7 +1698,7 @@ ALTER TABLE filter
 `,
 	`UPDATE  irc_network
     SET server = 'irc.animefriends.moe',
-        name = CASE  
+        name = CASE
 			WHEN name = 'AnimeBytes-IRC' THEN 'AnimeBytes'
         	ELSE name
         END
@@ -1777,11 +1777,11 @@ CREATE INDEX filter_priority_index
 	`UPDATE irc_network
 	SET server = 'irc.scenehd.org'
 	WHERE server = 'irc.scenehd.eu';
-	
+
 UPDATE irc_network
 	SET server = 'irc.p2p-network.net', name = 'P2P-Network', nick = nick || '_0'
 	WHERE server = 'irc.librairc.net';
-	
+
 UPDATE irc_network
 	SET server = 'irc.atw-inter.net', name = 'ATW-Inter'
 	WHERE server = 'irc.ircnet.com';
@@ -1815,6 +1815,7 @@ UPDATE irc_network
     tags_excluded            TEXT [] DEFAULT '{}' NOT NULL,
     include_unmonitored      BOOLEAN,
     include_alternate_titles BOOLEAN,
+    skip_clean_sanitize      BOOLEAN DEFAULT FALSE,
     last_refresh_time        TIMESTAMP,
     last_refresh_status      TEXT,
     last_refresh_data        TEXT,
@@ -1985,7 +1986,7 @@ CREATE INDEX release_cut_index
 CREATE INDEX release_hybrid_index
     ON "release" (hybrid);
 `,
-	`UPDATE irc_channel 
+	`UPDATE irc_channel
     SET name = '#ptp-announce'
     WHERE name = '#ptp-announce-dev' AND NOT EXISTS (SELECT 1 FROM irc_channel WHERE name = '#ptp-announce');
 `,
@@ -1996,5 +1997,26 @@ CREATE INDEX release_hybrid_index
 	`UPDATE filter
 	SET announce_types = '{"NEW"}'
 	WHERE announce_types = '{}';
+`,
+	`
+	ALTER TABLE list
+		ADD COLUMN skip_clean_sanitize BOOLEAN DEFAULT FALSE;
+`,
+	`UPDATE irc_network 
+	SET 
+    	auth_mechanism = 'NONE',
+    	auth_account = '',
+    	auth_password = ''
+	WHERE server = 'irc.rocket-hd.cc' 
+    	AND auth_mechanism != 'NONE';
+
+	UPDATE irc_channel 
+	SET password = NULL
+	WHERE password IS NOT NULL
+    	AND network_id IN (
+        	SELECT id 
+        	FROM irc_network 
+        	WHERE server = 'irc.rocket-hd.cc'
+    	);
 `,
 }
